@@ -1151,6 +1151,7 @@ impl Backup {
 pub enum DownloadEvent {
     Init(DownloadEventInit),
     Progress(DownloadEventProgress),
+    Retry(DownloadEventRetry),
     Completed(DownloadEventCompleted),
 }
 
@@ -1167,6 +1168,12 @@ pub struct DownloadEventProgress {
     pub total: i64,
 }
 
+#[cfg(feature = "git")]
+#[derive(Debug, Eq, PartialEq, Copy, Clone, Ord, PartialOrd, Hash)]
+pub struct DownloadEventRetry {
+    pub resume: bool,
+}
+
 #[cfg(feature = "git")]
 #[derive(Debug, Eq, PartialEq, Copy, Clone, Ord, PartialOrd, Hash)]
 pub struct DownloadEventCompleted {
